<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="uk" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="53"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Automatically save documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Restore window geometry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Restore live preview state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Open external links in ReText window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Open unknown files in plain text mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Highlight current line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Show line numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Tab key inserts spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Tabulation width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Display right margin at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Icon theme name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Markdown extensions (comma-separated)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Color scheme file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="53"/>
        <source>Stylesheet file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="21"/>
        <source>(none)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="28"/>
        <source>Select file to open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="32"/>
        <source>Enter locale name (example: en_US)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialogs.py" line="37"/>
        <source>Set as default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="61"/>
        <source>File toolbar</source>
        <translation>Панель файлу</translation>
    </message>
    <message>
        <location filename="window.py" line="63"/>
        <source>Edit toolbar</source>
        <translation>Панель редагування</translation>
    </message>
    <message>
        <location filename="window.py" line="65"/>
        <source>Search toolbar</source>
        <translation>Панель пошуку</translation>
    </message>
    <message>
        <location filename="window.py" line="69"/>
        <source>New</source>
        <translation>Новий</translation>
    </message>
    <message>
        <location filename="window.py" line="72"/>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <location filename="window.py" line="80"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="window.py" line="84"/>
        <source>Save as</source>
        <translation>Зберегти як</translation>
    </message>
    <message>
        <location filename="window.py" line="90"/>
        <source>Print</source>
        <translation>Друкувати</translation>
    </message>
    <message>
        <location filename="window.py" line="93"/>
        <source>Print preview</source>
        <translation>Попередній перегляд перед друком</translation>
    </message>
    <message>
        <location filename="window.py" line="95"/>
        <source>View HTML code</source>
        <translation>Переглянути код HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Change default font</source>
        <translation>Змінити шрифт по замовчуванню</translation>
    </message>
    <message>
        <location filename="window.py" line="97"/>
        <source>Find text</source>
        <translation>Знайти текст</translation>
    </message>
    <message>
        <location filename="window.py" line="101"/>
        <source>Preview</source>
        <translation>Перегляд</translation>
    </message>
    <message>
        <location filename="window.py" line="110"/>
        <source>Live preview</source>
        <translation>Одночасний перегляд</translation>
    </message>
    <message>
        <location filename="window.py" line="114"/>
        <source>Fullscreen mode</source>
        <translation>На весь екран</translation>
    </message>
    <message>
        <location filename="window.py" line="122"/>
        <source>Quit</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Undo</source>
        <translation>Відмінити дію</translation>
    </message>
    <message>
        <location filename="window.py" line="127"/>
        <source>Redo</source>
        <translation>Повторити дію</translation>
    </message>
    <message>
        <location filename="window.py" line="129"/>
        <source>Copy</source>
        <translation>Скопіювати</translation>
    </message>
    <message>
        <location filename="window.py" line="131"/>
        <source>Cut</source>
        <translation>Вирізати</translation>
    </message>
    <message>
        <location filename="window.py" line="133"/>
        <source>Paste</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <location filename="window.py" line="143"/>
        <source>Enable</source>
        <translation>Увімкнути</translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>Set locale</source>
        <translation>Вибрати мову</translation>
    </message>
    <message>
        <location filename="window.py" line="145"/>
        <source>Plain text</source>
        <translation>Простий текст</translation>
    </message>
    <message>
        <location filename="window.py" line="146"/>
        <source>Use WebKit renderer</source>
        <translation>Використовувати WebKit</translation>
    </message>
    <message>
        <location filename="window.py" line="148"/>
        <source>Generate webpages</source>
        <translation>Створити веб-сторінки</translation>
    </message>
    <message>
        <location filename="window.py" line="149"/>
        <source>Show</source>
        <translation>Показати</translation>
    </message>
    <message>
        <location filename="window.py" line="150"/>
        <source>Next</source>
        <translation>Наступне</translation>
    </message>
    <message>
        <location filename="window.py" line="152"/>
        <source>Previous</source>
        <translation>Попереднє</translation>
    </message>
    <message>
        <location filename="window.py" line="154"/>
        <source>Get help online</source>
        <translation>Отримати довідку в мережі</translation>
    </message>
    <message>
        <location filename="window.py" line="155"/>
        <source>About %s</source>
        <comment>Example of final string: About ReText</comment>
        <translation>Про %s</translation>
    </message>
    <message>
        <location filename="window.py" line="159"/>
        <source>About Qt</source>
        <translation>Про Qt</translation>
    </message>
    <message>
        <location filename="window.py" line="179"/>
        <source>Bold</source>
        <translation>Потовщення</translation>
    </message>
    <message>
        <location filename="window.py" line="181"/>
        <source>Italic</source>
        <translation>Нахил</translation>
    </message>
    <message>
        <location filename="window.py" line="183"/>
        <source>Underline</source>
        <translation>Підкреслення</translation>
    </message>
    <message>
        <location filename="window.py" line="191"/>
        <source>Tags</source>
        <translation>Теги</translation>
    </message>
    <message>
        <location filename="window.py" line="195"/>
        <source>Symbols</source>
        <translation>Символи</translation>
    </message>
    <message>
        <location filename="window.py" line="209"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="window.py" line="210"/>
        <source>Edit</source>
        <translation>Редагування</translation>
    </message>
    <message>
        <location filename="window.py" line="211"/>
        <source>Help</source>
        <translation>Довідка</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>Open recent</source>
        <translation>Відкрити останній</translation>
    </message>
    <message>
        <location filename="window.py" line="217"/>
        <source>Directory</source>
        <translation>Тека</translation>
    </message>
    <message>
        <location filename="window.py" line="229"/>
        <source>Export</source>
        <translation>Експорт</translation>
    </message>
    <message>
        <location filename="window.py" line="250"/>
        <source>Spell check</source>
        <translation>Перевірка правопису</translation>
    </message>
    <message>
        <location filename="window.py" line="261"/>
        <source>Formatting</source>
        <translation>Форматування</translation>
    </message>
    <message>
        <location filename="window.py" line="299"/>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <location filename="window.py" line="301"/>
        <source>Case sensitively</source>
        <translation>Врахувати регістр</translation>
    </message>
    <message>
        <location filename="window.py" line="1128"/>
        <source>New document</source>
        <translation>Новий документ</translation>
    </message>
    <message>
        <location filename="window.py" line="648"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>Неможливо розпізнати вміст фалу, перевірте наявність &lt;a href=&quot;%s&quot;&gt;необхідних модулів&lt;/a&gt;!</translation>
    </message>
    <message>
        <location filename="window.py" line="746"/>
        <source>Please, save the file somewhere.</source>
        <translation>Будь ласка, збережіть кудись файл.</translation>
    </message>
    <message>
        <location filename="window.py" line="731"/>
        <source>Failed to copy default template, please create template.html manually.</source>
        <translation>Не вдалось скопіювати шаблон по замовчуванню, будь ласка, створіть  template.html самостійно.</translation>
    </message>
    <message>
        <location filename="window.py" line="735"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Веб-сторінки збережено в &lt;code&gt;html&lt;/code&gt; теці.</translation>
    </message>
    <message>
        <location filename="window.py" line="737"/>
        <source>Show directory</source>
        <translation>Переглянути теку</translation>
    </message>
    <message>
        <location filename="window.py" line="865"/>
        <source>Select one or several files to open</source>
        <translation>Виберіть один або кілька файлів</translation>
    </message>
    <message>
        <location filename="window.py" line="865"/>
        <source>Supported files</source>
        <translation>Файли що підтримуються</translation>
    </message>
    <message>
        <location filename="window.py" line="865"/>
        <source>All files (*)</source>
        <translation>Всі файли (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="949"/>
        <source>Plain text (*.txt)</source>
        <translation>Простий текст (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="952"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>Файли %s</translation>
    </message>
    <message>
        <location filename="window.py" line="1027"/>
        <source>Save file</source>
        <translation>Зберегти файл</translation>
    </message>
    <message>
        <location filename="window.py" line="972"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Неможливо зберегти, файл тільки для читання!</translation>
    </message>
    <message>
        <location filename="window.py" line="1017"/>
        <source>Export document to ODT</source>
        <translation>Експортувати як ODT</translation>
    </message>
    <message>
        <location filename="window.py" line="1017"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Текстові файли OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="1027"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Файли HTML (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="1049"/>
        <source>Export document to PDF</source>
        <translation>Експортувати як PDF</translation>
    </message>
    <message>
        <location filename="window.py" line="1049"/>
        <source>PDF files (*.pdf)</source>
        <translation>Файли PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="1066"/>
        <source>Print document</source>
        <translation>Друкувати документ</translation>
    </message>
    <message>
        <location filename="window.py" line="1087"/>
        <source>Export document</source>
        <translation>Експортувати документ</translation>
    </message>
    <message>
        <location filename="window.py" line="1106"/>
        <source>Failed to execute the command:</source>
        <translation>Помилка при виконанні команди:</translation>
    </message>
    <message>
        <location filename="window.py" line="1187"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Документ було змінено.
Бажаєте зберегти ці зміни?</translation>
    </message>
    <message>
        <location filename="window.py" line="1211"/>
        <source>HTML code</source>
        <translation>Код HTML</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Простий але потужний текстовий редактор для Markdown та reStructuredText
</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Автор: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>Markdown syntax</source>
        <translation>Синтаксис Markdown</translation>
    </message>
    <message>
        <location filename="window.py" line="1222"/>
        <source>reStructuredText syntax</source>
        <translation>Синтаксис reStructuredText</translation>
    </message>
    <message>
        <location filename="window.py" line="258"/>
        <source>Default markup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="574"/>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="75"/>
        <source>Set encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="924"/>
        <source>Select file encoding from the list:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="78"/>
        <source>Reload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="86"/>
        <source>Next tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="88"/>
        <source>Previous tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="112"/>
        <source>Table mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
